@@ -1,6 +1,6 @@
 #ifdef E_TYPEDEFS
 
-#define E_MODULE_API_VERSION 21
+#define E_MODULE_API_VERSION 25
 
 typedef struct _E_Module     E_Module;
 typedef struct _E_Module_Api E_Module_Api;
@@ -21,7 +21,7 @@ extern E_API int E_EVENT_MODULE_INIT_END;
 struct _E_Event_Module_Update
 {
    const char *name;
-   Eina_Bool enabled : 1;
+   Eina_Bool enabled E_BITFIELD;
 };
 
 struct _E_Module
@@ -31,6 +31,7 @@ struct _E_Module
    E_Module_Api        *api;
 
    Eina_Stringshare    *name;
+   Eina_Stringshare    *file;
    Eina_Stringshare    *dir;
    void                *handle;
 
@@ -40,8 +41,8 @@ struct _E_Module
       int    (*save)        (E_Module *m);
    } func;
 
-   Eina_Bool        enabled : 1;
-   Eina_Bool        error : 1;
+   Eina_Bool        enabled E_BITFIELD;
+   Eina_Bool        error E_BITFIELD;
 
    /* the module is allowed to modify these */
    void                *data;
